@@ -64,9 +64,11 @@ def get_histograms(sdata, category=None,resolution=5):
 
     return histograms
 
-import pdb;
+# import pdb;
 
 def _interpolate(x,y,step):
+
+    from scipy import interpolate 
     """_interpolat generates linear interpolation from the x,y to create mutual distance curves in um units
 
     :param x: distances with available values
@@ -77,7 +79,11 @@ def _interpolate(x,y,step):
     :type step: float
     """
 
-    return np.apply_along_axis(lambda x_: np.interp(np.arange(0,x.max()*step),x*step,x_,),2,y)
+    # return lambda x_ :  interpolate.BSpline(*interpolate.splrep(x,y,s=0,k=5), extrapolate=False)
+
+    return np.apply_along_axis(lambda x_ :  interpolate.BSpline(*interpolate.splrep(x,x_,s=0,k=5), extrapolate=False)(np.arange(0,x.max()*step)),2,y)
+    # return lambda x_ : np.apply_along_axis( Akima1DInterpolator(x,x_)(np.arange(0,x.max()*step)),2,y)
+        # return np.apply_along_axis(lambda x_: np.interp(np.arange(0,x.max()*step),x*step,x_,),2,y)
 
 def co_occurrence(sdata, resolution=5.0, max_radius=400, linear_steps=5, category=None):
     """co_occurrence _summary_
@@ -133,6 +139,8 @@ def co_occurrence(sdata, resolution=5.0, max_radius=400, linear_steps=5, categor
             co_occurrences[j,i]= co_occurrences[i,j]
 
     return _interpolate(radii, co_occurrences,resolution)
+    # return radii, co_occurrences
+
 
 def ripleys_k(sdata, resolution=5, max_radius=400, linear_steps=5, category=None):
 
