@@ -6,7 +6,7 @@ import numpy as np
 # from numpy.ma.extras import _covhelper
 # from numpy.ma.core import dot
 
-from requests import patch
+# from requests import patch
 from scipy.ndimage import gaussian_filter, maximum_filter
 from plankton.pixelmaps import PixelMap
 
